@@ -43,10 +43,10 @@ gammaCK2par <- function(matAp, matBp, n.cores = NULL, cut.a = 0.92, method = "jw
     matBp[matBp == ""] <- NA
 
     if(sum(is.na(matAp)) == length(matAp) | length(unique(matAp)) == 1){
-        cat("WARNING: You have no variation in this variable, or all observations are missing in dataset A.")
+        cat("WARNING: You have no variation in this variable, or all observations are missing in dataset A.\n")
     }
     if(sum(is.na(matBp)) == length(matBp) | length(unique(matBp)) == 1){
-        cat("WARNING: You have no variation in this variable, or all observations are missing in dataset B.")
+        cat("WARNING: You have no variation in this variable, or all observations are missing in dataset B.\n")
     }
 
     if(!(method %in% c("jw", "jaro", "lv"))){
@@ -127,17 +127,20 @@ gammaCK2par <- function(matAp, matBp, n.cores = NULL, cut.a = 0.92, method = "jw
 
     do <- expand.grid(1:n.slices2, 1:n.slices1)
 
-    nc <- n.cores
-    cl <- makeCluster(nc)
-    registerDoParallel(cl)
+    if (n.cores == 1) '%oper%' <- foreach::'%do%'
+    else { 
+        '%oper%' <- foreach::'%dopar%'
+        cl <- makeCluster(n.cores)
+        registerDoParallel(cl)
+        on.exit(stopCluster(cl))
+    }
 
-    temp.f <- foreach(i = 1:nrow(do), .packages = c("stringdist", "Matrix")) %dopar% {
+    temp.f <- foreach(i = 1:nrow(do), .packages = c("stringdist", "Matrix")) %oper% {
         r1 <- do[i, 1]
         r2 <- do[i, 2]
         stringvec(temp.1[[r1]], temp.2[[r2]], cut.a)
     }
 
-    stopCluster(cl)
     gc()
 
     reshape2 <- function(s) { s[[1]] }
@@ -152,21 +155,30 @@ gammaCK2par <- function(matAp, matBp, n.cores = NULL, cut.a = 0.92, method = "jw
     matches.2 <- lapply(seq_len(nrow(n.values.2)), function(i) n.values.2[i, ])
 
     if(Sys.info()[['sysname']] == 'Windows') {
-        nc <- n.cores
-    		cl <- makeCluster(nc)
-    		registerDoParallel(cl)
-
-    		final.list2 <- foreach(i = 1:length(matches.2)) %dopar% {
+        if (n.cores == 1) '%oper%' <- foreach::'%do%'
+        else { 
+            '%oper%' <- foreach::'%dopar%'
+            cl <- makeCluster(n.cores)
+            registerDoParallel(cl)
+            on.exit(stopCluster(cl))
+        }
+        if(length(matches.2) > 0) {
+            final.list2 <- foreach(i = 1:length(matches.2)) %oper% {
             ht1 <- which(matrix.1 == matches.2[[i]][[1]]); ht2 <- which(matrix.2 == matches.2[[i]][[2]])
             list(ht1, ht2)
-      	}
-    		stopCluster(cl)
+      	  }
+        }    
     } else {
         no_cores <- n.cores
-    		final.list2 <- mclapply(matches.2, function(s){
+            final.list2 <- mclapply(matches.2, function(s){
             ht1 <- which(matrix.1 == s[1]); ht2 <- which(matrix.2 == s[2]);
             list(ht1, ht2) }, mc.cores = getOption("mc.cores", no_cores))
     }
+
+    if(length(matches.2) == 0){ 
+      final.list2 <- list()
+      warning("There are no identical (or nearly identical) matches. We suggest either changing the value of cut.p") 
+    }
     
     na.list <- list()
     na.list[[1]] <- which(matrix.1 == "9999")
